@@ -70,8 +70,10 @@ public final class DavGatewayHttpClientFacade {
     private static IdleConnectionTimeoutThread httpConnectionManagerThread;
 
     static {
-        // workaround for TLS Renegotiation issue see http://java.sun.com/javase/javaseforbusiness/docs/TLSReadme.html    
-        System.setProperty("sun.security.ssl.allowUnsafeRenegotiation", "true");
+        // disable Client-initiated TLS renegotiation
+        System.setProperty("jdk.tls.rejectClientInitiatedRenegotiation", "true");
+            // force strong ephemeral Diffie-Hellman parameter
+        System.setProperty("jdk.tls.ephemeralDHKeySize", "2048");
 
         DavGatewayHttpClientFacade.start();
 
